@@ -11,7 +11,7 @@ import shutil
 class CentralReachCore(SitesCore):
     def __init__(self, login: str, password: str, url: str = 'https://members.centralreach.com/#login',
                  start_date: date = date.today().replace(day=1), end_date: date = date.today(),
-                 timeout: int = 30, temp_folder: str = '') -> None:
+                 timeout: int = 30, temp_folder: str = ''):
         """
         CentralReachCore object. Please Inheritance it.
 
@@ -72,7 +72,7 @@ class CentralReachCore(SitesCore):
                 logging.error(f'Logging into CentralReach. Attempt #{i} failed')
                 logging.error(str(ex))
                 self.browser.capture_page_screenshot(
-                    os.path.join(self.output_folder, f'Centralreach_login_failed_{i}.png')
+                    os.path.join(self.output_folder, f'Login_failed_Attempt_{i}.png')
                 )
                 self.browser.close_browser()
         return False
